%{?mingw_package_header}

%global pkgname openjpeg2
%global upver 2.1

Name:           mingw-%{pkgname}
Version:        2.1.0
Release:        2%{?dist}
Summary:        MinGW Windows %{pkgname} library

# windirent.h is MIT, the rest is BSD
License:        BSD and MIT
BuildArch:      noarch
URL:            https://github.com/uclouvain/openjpeg
Source0:        https://github.com/uclouvain/openjpeg/archive/version.%{upver}.tar.gz

# Remove bundled libraries
Patch0:         openjpeg2_remove-thirdparty.patch
# Bigendian fixes
Patch1:         openjpeg2_bigendian.patch
# Backport fix for use after free vulnerability (#1263359)
Patch2:         940100c28ae28931722290794889cf84a92c5f6f.patch
# Backport fix for possible double-free (#1267983)
Patch3:         0fa5a17c98c4b8f9ee2286f4f0a50cf52a5fccb0.patch

BuildRequires:  cmake

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-zlib
BuildRequires:  mingw32-libpng
BuildRequires:  mingw32-libtiff
BuildRequires:  mingw32-lcms2

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-zlib
BuildRequires:  mingw64-libpng
BuildRequires:  mingw64-libtiff
BuildRequires:  mingw64-lcms2


%description
MinGW Windows %{pkgname} library.


%package -n mingw32-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw32-%{pkgname}
%{summary}.


%package -n mingw32-%{pkgname}-tools
Summary:       Tools for the MinGW Windows %{pkgname} library
Requires:      mingw32-%{pkgname} = %{version}-%{release}

%description -n mingw32-%{pkgname}-tools
%{summary}.


%package -n mingw64-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw64-%{pkgname}
%{summary}.


%package -n mingw64-%{pkgname}-tools
Summary:       Tools for the MinGW Windows %{pkgname} library
Requires:      mingw64-%{pkgname} = %{version}-%{release}

%description -n mingw64-%{pkgname}-tools
%{summary}.


%{?mingw_debug_package}


%prep
%setup -q -n openjpeg-version.%{upver} %{?runcheck:-a 1}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# Remove all third party libraries just to be sure
rm -rf thirdparty


%build
%mingw_cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DBUILD_PKGCONFIG_FILES=ON .
%mingw_make VERBOSE=1 %{?_smp_mflags}


%install
%mingw_make install DESTDIR=%{buildroot}

# Rename to avoid conflicts with openjpeg-1.x
for file in %{buildroot}%{mingw32_bindir}/opj_*; do
    mv $file ${file/opj_/opj2_}
done
for file in %{buildroot}%{mingw64_bindir}/opj_*; do
    mv $file ${file/opj_/opj2_}
done

# Delete files to exclude from package
rm -rf %{buildroot}%{mingw32_mandir}
rm -rf %{buildroot}%{mingw64_mandir}
rm -rf %{buildroot}%{mingw32_datadir}/doc
rm -rf %{buildroot}%{mingw64_datadir}/doc


%files -n mingw32-%{pkgname}
%license LICENSE
%{mingw32_bindir}/libopenjp2.dll
%{mingw32_libdir}/libopenjp2.dll.a
%{mingw32_includedir}/openjpeg-2.1/
%{mingw32_libdir}/openjpeg-2.1/
%{mingw32_libdir}/pkgconfig/libopenjp2.pc

%files -n mingw32-%{pkgname}-tools
%{mingw32_bindir}/opj2_compress.exe
%{mingw32_bindir}/opj2_decompress.exe
%{mingw32_bindir}/opj2_dump.exe

%files -n mingw64-%{pkgname}
%license LICENSE
%{mingw64_bindir}/libopenjp2.dll
%{mingw64_libdir}/libopenjp2.dll.a
%{mingw64_includedir}/openjpeg-2.1/
%{mingw64_libdir}/openjpeg-2.1/
%{mingw64_libdir}/pkgconfig/libopenjp2.pc

%files -n mingw64-%{pkgname}-tools
%{mingw64_bindir}/opj2_compress.exe
%{mingw64_bindir}/opj2_decompress.exe
%{mingw64_bindir}/opj2_dump.exe


%changelog
* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Sep 17 2015 Sandro Mani <manisandro@gmail.com> - 2.1.0-1
- Initial package